@@ -113,27 +113,31 @@ is inserted before the cursor, the short name is expanded to its address."
 (defun mew-complete-local-folder ()
   "Local folder complete function."
   (interactive)
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-complete-folder-ignore-case))
-  (let ((word (mew-delete-backward-char))
-        (completion-ignore-case mew-complete-folder-ignore-case))
-    (if (null word)
-        (mew-complete-window-show (list "+"))
-      (if (and (mew-folder-absolutep word)
-	       (not (mew-draft-or-header-p)))
-	  (mew-complete word (mew-complete-directory-alist word) "directory" nil)
-	(mew-complete word (mew-local-folder-alist) "folder" nil)))))
+  (if mew-input-folder-search-direction
+      (mew-input-folder-search-complete)
+    (when (mew-draft-or-header-p)
+      (setq completion-ignore-case mew-complete-folder-ignore-case))
+    (let ((word (mew-delete-backward-char))
+	  (completion-ignore-case mew-complete-folder-ignore-case))
+      (if (null word)
+	  (mew-complete-window-show (list "+"))
+	(if (and (mew-folder-absolutep word)
+		 (not (mew-draft-or-header-p)))
+	    (mew-complete word (mew-complete-directory-alist word) "directory" nil)
+	  (mew-complete word (mew-local-folder-alist) "folder" nil))))))
 
 (defun mew-complete-imap-folder ()
   "IMAP folder complete function."
   (interactive)
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-complete-folder-ignore-case))
-  (let ((word (mew-delete-backward-char))
-        (completion-ignore-case mew-complete-folder-ignore-case))
-    (if (null word)
-        (mew-complete-window-show (list "%"))
-      (mew-complete word (mew-imap-folder-alist mew-inherit-case) "mailbox" nil))))
+  (if mew-input-folder-search-direction
+      (mew-input-folder-search-complete)
+    (when (mew-draft-or-header-p)
+      (setq completion-ignore-case mew-complete-folder-ignore-case))
+    (let ((word (mew-delete-backward-char))
+	  (completion-ignore-case mew-complete-folder-ignore-case))
+      (if (null word)
+	  (mew-complete-window-show (list "%"))
+	(mew-complete word (mew-imap-folder-alist mew-inherit-case) "mailbox" nil)))))
 
 (defun mew-complete-folder ()
   "Folder complete function."
