@@ -233,6 +233,9 @@
 (defsubst mew-regex-jmp-msg (msg)
   (concat  "^[ ]*" msg "[^0-9]"))
 
+(defconst mew-regex-case "^\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):")
+(defconst mew-regex-case2 "\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):")
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Folder
