@@ -925,7 +925,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 	       (setq med (match-end 0))
 	       (forward-line)
 	       (mew-header-goto-next)
-	       (setq str (buffer-substring med (1- (point))))
+	       (setq str (mew-buffer-substring med (1- (point))))
 	       ;; str may consists of multiple lines
 	       ;; So, "$" does not work. We need to use "[^ ]".
 	       (unless (string-match "[^ \t\n]" str)
