@@ -709,9 +709,11 @@ The message is assumed to be a valid MIME message."
        (setq inf (mew-lisp-load info))
        (cond
 	((mew-folder-queuep fld)
-	 (setq hdr (mew-smtp-get-raw-header inf)))
+	 (setq hdr (mew-smtp-get-raw-header inf))
+	 (mew-tinfo-set-case (mew-smtp-get-case inf)))
 	((mew-folder-postqp fld)
-	 (setq hdr (mew-nntp2-get-raw-header inf))))
+	 (setq hdr (mew-nntp2-get-raw-header inf))
+	 (mew-tinfo-set-case (mew-nntp2-get-case inf))))
        (mew-queue-backup file mew-queue-info-suffix)
        (and hdr (mew-summary-edit-header-for-queue hdr))))
    (mew-draft-mode)
