@@ -457,6 +457,14 @@ all marked messages before the current message."
 ;;;
 
 (defun mew-summary-exec-offline (&optional arg)
+  "\\<mew-summary-mode-map>Process marked messages *offline*. Messages to be refiled in 
+a remote folder are moved to the corresponding folder but they are
+marked invalid. A number of an invalid message starts with '0'.
+Invalid messages will be overridden when the remote folder
+is scanned online. 
+A job to delete or refile messages, which is created by this command, 
+is queued in a queue folder (%queue for IMAP). To flush jobs in 
+the queue, type '\\[mew-summary-send-message]' in the queue online."
   (interactive "P")
   (if (not (mew-folder-imapp (mew-sinfo-get-folder)))
       (message "This command cannot be used in this folder")
