@@ -159,6 +159,21 @@ This is O(N^2). So, do not use this function with a large LST."
 	    (throw 'loop a))
 	(setq alist (cdr alist))))))
 
+(defun mew-assoc-folder (key alist localp)
+  (let ((skey (downcase key))
+	(regex (concat mew-path-separator "$"))
+	a n ret)
+    (catch 'loop
+      (while alist
+	(setq a (car alist))
+	(setq n (nth 1 a))
+	(when (and (stringp n) (string= (downcase n) skey))
+	  (setq ret a)
+	  (unless (and localp (string-match regex (car a)))
+	    (throw 'loop nil)))
+	(setq alist (cdr alist))))
+    ret))
+
 (defun mew-assoc-match (key alist nth)
   "Return list in ALIST that KEY regex is matched to its NTH element.
 Case is ignored. Note that the NTH element is 't', 
