@@ -86,7 +86,7 @@ at completions."
 (defun mew-highlight-folder-comp-search-window ()
   (let* ((win (get-buffer-window mew-buffer-completions))
 	 (match mew-input-folder-search-match)
-	 regex face)
+	 face)
     (when (and win
 	       mew-input-folder-search-key
 	       mew-input-folder-search-match)
@@ -99,9 +99,8 @@ at completions."
 	 (insert "Key: " mew-input-folder-search-key ",  "
 		 "Match: " mew-input-folder-search-match "\n")
 	 (put-text-property (point-min) (point-max) 'face nil)
-	 (setq regex (format "\\(%s\\)" (regexp-quote match)))
-	 (when (or (re-search-forward (concat regex "[ \t]") nil t)
-		   (re-search-forward (concat regex "$") nil t))
+	 (when (re-search-forward
+		(format "\\(%s\\)\\([ \t]\\|$\\)" (regexp-quote match)) nil t)
 	   (goto-char (match-beginning 1))
 	   (setq face (if (not window-system)
 			  'mew-face-header-from
