@@ -449,9 +449,16 @@ If called with '\\[universal-argument]', +queue is not flushed."
 ;;;
 
 (defun mew-summary-retrieve-message (&optional rev-del)
-  "Retrieve the rest of a truncated('T') message.
-If 'mew-pop-delete'/'mew-imap-delete' is 't', delete the message 
-from the mailbox. When executed with '\\[universal-argument]', 
+  "Retrieve the rest of a truncated('T') message.  
+
+If you use this command in a LOCAL folder and
+'mew-pop-delete'/'mew-imap-delete' is 't', delete the message from the
+mailbox.
+
+If you use this command in a REMOTE folder, the message in the server
+side is always retained.
+
+When executed with '\\[universal-argument]',
 'mew-pop-delete'/'mew-imap-delete' is considered reversed."
   (interactive "P")
   (mew-summary-msg
@@ -494,9 +501,16 @@ from the mailbox. When executed with '\\[universal-argument]',
 	      (mew-nntp-retrieve case 'get bnm rtrs))))))))))
 
 (defun mew-summary-mark-retrieve-message (&optional rev-del)
-  "Retrieve the rest of truncated('T') messages marked with '*'.
-If 'mew-pop-delete'/'mew-imap-delete' is 't', delete the message 
-from the mailbox. When executed with '\\[universal-argument]', 
+  "Retrieve the rest of truncated('T') messages marked with '*'. 
+
+If you use this command in a LOCAL folder and
+'mew-pop-delete'/'mew-imap-delete' is 't', delete the message from the
+mailbox. 
+
+If you use this command in a REMOTE folder, the message in the server
+side is always retained.
+
+When executed with '\\[universal-argument]',
 'mew-pop-delete'/'mew-imap-delete' is considered reversed."
   (interactive "P")
   (mew-summary-only
