@@ -20,10 +20,11 @@
 ;;;
 
 (defvar mew-nntp-info-list
-  '("server" "port" "user" "process" "ssh-process" "status"
+  '("server" "port" "process" "ssh-process" "status"
     "directive" "bnm"
     "rtrs" "refs" "range"
     "rttl" "rcnt" "hlds"
+    "user"
     "size" "get-body" "no-msg" "case" "msgdb" "done"
     "newsgroup" "msgid" "truncated"))
 
