@@ -132,13 +132,14 @@ mew-refile-guess-from-me-is-special."
 	 (proto (mew-sinfo-get-proto))
 	 (case (mew-sinfo-get-case))
 	 (alist (mew-proto-folder-alist proto case))
+	 (localp (mew-folder-localp proto))
 	 ent ret ml-addr ml-name)
     (while to-cc
       (setq ml-addr (mew-addrstr-parse-address (or (car to-cc) "")))
       (when ml-addr
 	(setq ml-name (mew-addrstr-extract-user ml-addr))
-	(setq ent (or (mew-assoc-case-equal ml-addr alist 1)
-		      (mew-assoc-case-equal ml-name alist 1)))
+	(setq ent (or (mew-assoc-folder ml-addr alist localp)
+		      (mew-assoc-folder ml-name alist localp)))
 	(mew-addq ret (nth 0 ent)))
       (setq to-cc (cdr to-cc)))
     (nreverse ret)))
