@@ -552,9 +552,12 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-isearch-backward]	Incremental search backward in
 	Message mode.
 
-\\[mew-summary-print]	Print this message or this part.
+\\[mew-summary-print]	Print the content of Message mode according to 'mew-print-function'.
+	If called with '\\[universal-argument]', you can specify a printer name.
 
-\\[mew-summary-pipe-message]	Send this message via pipe.
+\\[mew-summary-pipe-message]	Send the content of Message buffer to a command via pipe.
+	If called with '\\[universal-argument]', the body of the message
+	(excluding its header) is sent.
 
 \\[mew-summary-send-message]	If in +queue, send the messages in +queue.
 	If in +postq, post the messages in +postq.
@@ -564,7 +567,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 
 
 \\[mew-summary-toggle-8bit]	Toggle 8bit mode(i.e. 'mew-use-8bit').
-\\[mew-summary-cache-clean-up]	Clean-up caches of analized messages.
+\\[mew-summary-cache-clean-up]	Clean-up caches of analyzed messages.
 \\[mew-summary-toggle-warning]	Toggle waring level.
 	If 'mew-warning-field-level' is 2, set it to 1.
 	If 'mew-warning-field-level' is 1, set it to 2.
@@ -618,7 +621,9 @@ Virtual mode.
 	A job to delete or refile messages, which is created by this command, 
 	is queued in a queue folder (%queue for IMAP). To flush jobs in 
 	the queue, type '\\[mew-summary-send-message]' in the queue online.
-\\[mew-summary-local-copy]	Copying a cached message in a remote folder to a local folder.
+\\[mew-summary-local-copy]	Copy a cached message in a remote folder to a local folder.
+\\[mew-summary-mark-local-copy]	Copy cached message marked with '*' in a remote folder to a local
+folder.
 
 \\[mew-summary-search-mark]	Pick messages according to a pick pattern
 	which you input, then put the '*' mark onto them. If called
