@@ -277,7 +277,9 @@ the top message is then displayed."
 ;;;
 
 (defun mew-summary-pipe-message (prefix command)
-  "Send this message via pipe."
+  "Send the content of Message buffer to a command via pipe.
+If called with '\\[universal-argument]', the body of the message
+(excluding its header) is sent."
   (interactive
    (list current-prefix-arg 
 	 (read-string "Shell command on message: " mew-last-shell-command)))
@@ -300,7 +302,8 @@ the top message is then displayed."
 ;;;
 
 (defun mew-summary-print (&optional arg)
-  "Print this message or this part according to 'mew-print-function'."
+  "Print the content of Message mode according to 'mew-print-function'.
+If called with '\\[universal-argument]', you can specify a printer name."
   (interactive "P")
   (mew-summary-display 'redisplay)
   (when (y-or-n-p "Print this message? ")
@@ -802,7 +805,7 @@ to clean up."
 ;;;
 
 (defun mew-summary-local-copy ()
-  "Copying a cached message in a remote folder to a local folder."
+  "Copy a cached message in a remote folder to a local folder."
   (interactive)
   (mew-summary-msg-or-part
    (let ((fld (mew-summary-folder-name))
@@ -812,7 +815,8 @@ to clean up."
        (mew-summary-goto-message)
        (setq msg (mew-summary-message-number)))
      (setq file (mew-expand-folder fld msg))
-     (setq dstfld (mew-input-folder mew-inbox-folder)) ;; xxx
+     (setq dstfld (mew-input-folder mew-inbox-folder)) ;; local folder only
+     (mew-local-folder-check dstfld)
      (setq dstmsg (mew-folder-new-message dstfld 'numonly))
      (setq dstfile (mew-expand-folder dstfld dstmsg))
      (when (get-buffer dstfld)
@@ -829,7 +833,8 @@ to clean up."
        (message "Copied to %s/%s" dstfld dstmsg))))))
 
 (defun mew-summary-mark-local-copy (&optional arg)
-  "Copying marked cached message in a remote folder to a local folder."
+  "Copy cached message marked with '*' in a remote folder to a local
+folder."
   (interactive "P")
   (mew-summary-msg-or-part
    (let ((mew-use-highlight-x-face nil)
@@ -845,7 +850,8 @@ to clean up."
       (t
        (setq beg (point-min))
        (setq end (point-max))))
-     (setq dstfld (mew-input-folder mew-inbox-folder)) ;; xxx
+     (setq dstfld (mew-input-folder mew-inbox-folder)) ;; local folder only
+     (mew-local-folder-check dstfld)
      (setq dstmsg (mew-folder-new-message dstfld 'numonly))
      (setq msgs (mew-summary-mark-collect mew-mark-review beg end))
      (when (get-buffer dstfld)
@@ -933,7 +939,7 @@ you choose 'Summary mode only', you can quickly put the delete
 ;;;
 
 (defun mew-summary-cache-clean-up ()
-  "Clean-up caches of analized messages."
+  "Clean-up caches of analyzed messages."
   (interactive)
   (mew-cache-clean-up)
   (message "Mew cache clean up...done"))
